#!/bin/bash
#
# Installiert nach Abfrage der wichtigsten Parameter einen Drucker aus einer vorgegebenen Liste 
#
# Peter Somm: 09.02.18, 21.02.18, 27.02.18, 01.03.18, 25.10.18, 29.09.20
# Ronny Standtke: 03.06.20, 06.06.20, 08.10.20

# Parameter abfragen
printer_name="$(zenity --list \
	--title="Druckermodell 1.2" \
	--text="Welcher Drucker soll installiert werden?" \
	--radiolist \
	--column="" \
	--height=380 \
	--column="Modell" \
	FALSE "Kyocera Ecosys FS-1128MFP" \
	FALSE "Kyocera Ecosys FS-1135MFP" \
	FALSE "Kyocera Ecosys M2535dn"  \
	FALSE "Kyocera Ecosys M2540dn" \
	FALSE "Kyocera TASKalfa 4550ci" \
	FALSE "Kyocera TASKalfa 4551ci" \
	FALSE "Kyocera TASKalfa 5052ci" \
	FALSE "Kyocera TASKalfa 6551ci" \
	FALSE "HP LaserJet Flow MFP E52645" \
	FALSE "HP LaserJet MFP E87640-50-60" 2> /dev/null)"

echo "printer_name: \"$printer_name\""

if [ ! "$printer_name" ]; then exit; fi

# exakte Angabe des PPD-Dateinamens ist wichtig, auch Gross-/Kleinschreibung
case "$printer_name" in
	Kyocera*)
		driver_dir="Kyocera/German"
		print_server="print.schoolroot.net"
		;;
	HP*)
		driver_dir="HP"
		print_server="print.schoolwin.net"
		;;
esac
case "$printer_name" in
	'Kyocera Ecosys FS-1128MFP')
		ppd_name="Kyocera_FS-1128MFP.PPD"
		;;
	'Kyocera Ecosys FS-1135MFP')
		ppd_name="Kyocera_FS-1135MFP.ppd"
		;;
	'Kyocera Ecosys M2535dn')
		ppd_name="Kyocera ECOSYS M2535dn.PPD"
		;;
	'Kyocera Ecosys M2540dn')
		ppd_name="Kyocera ECOSYS M2540dn.PPD"
		;;
	'Kyocera TASKalfa 4550ci')
		ppd_name="Kyocera_TASKalfa_4550ci.PPD"
		;;
	'Kyocera TASKalfa 4551ci')
		ppd_name="Kyocera_TASKalfa_4551ci.PPD"
		;;
	'Kyocera TASKalfa 5052ci')
		ppd_name="Kyocera TASKalfa 5052ci.PPD"
		;;
	'Kyocera TASKalfa 6551ci')
		ppd_name="Kyocera_TASKalfa_6551ci.PPD"
		;;
	'HP LaserJet Flow MFP E52645')
		ppd_name="HP-LaserJet-Flow-MFP-E52645.ppd"
		;;
	'HP LaserJet MFP E87640-50-60')
		ppd_name="HP-LaserJet-MFP-E87640-50-60.ppd"
		;;
esac
ppd_path="/usr/share/cups/model/$driver_dir/$ppd_name"
echo "ppd_path: \"$ppd_path\""

printer_host_name="$(zenity --entry \
	--title="Hostname des Druckers" \
	--text="Wie lautet der Hostname des Druckers?\nTipp: Er steht auf dem Drucker." \
	--entry-text="EDxxxx" 2> /dev/null)"
printer_host_name="$(echo "$printer_host_name" | tr -d ' ')"
echo "printer_host_name: \"$printer_host_name\""
if [ ! "$printer_host_name" ]; then exit; fi
URI="socket://$printer_host_name.$print_server"
echo "URI: \"$URI\""

printer_description="$(zenity --entry \
	--title="Druckerbezeichnung" \
	--text="Wie soll der Drucker benannt werden?\nTipp: Es sind KEINE Leerzeichen erlaubt!" \
	--entry-text="mein_Schulzimmerdrucker" 2> /dev/null)"
printer_description="$(echo "$printer_description" | tr ' ' '_')"
echo "printer_description: \"$printer_description\""
if [ ! "$printer_description" ]; then exit; fi

zenity --question \
	--title="Druckstandard" \
	--text="Soll der Drucker einseitig oder doppelseitig drucken?" \
	--ok-label="doppelseitig" \
	--cancel-label="einseitig" 2> /dev/null
duplex=$?
echo "duplex: \"$duplex\""

zenity --question \
	--title="Standarddrucker" \
	--text="Soll der Drucker neu der Standardrucker sein?" \
	--ok-label="Ja" \
	--cancel-label="Nein" 2> /dev/null
default_printer=$?
echo "default_printer: \"$default_printer\""

# Drucker installieren
sudo lpadmin \
     -p "$printer_description" \
     -v "$URI" \
     -P "${ppd_path}" \
     -E

#     -L $Raum \
#     -m $printer_description \
#     -o 'Color=Mono' \
#     -o 'Enhance Black Printing=ON' \
#     -o 'Skip Blank Page=ON' \


# bei Bedarf doppelseitiges Drucken als Standard setzen
if [ $duplex -eq 0 ]
then
	sudo lpadmin -p "$printer_description" -o 'Duplex=DuplexNoTumble'
fi

# bei Bedarf neuen Drucker als Standarddrucker setzen
if [ $default_printer -eq 0 ]
then
	sudo lpadmin -d "$printer_description"
fi
